@@ -197,9 +197,9 @@
 #' 
 #' \code{2}: 2\eqn{\sigma} absolute uncertainties.
 #' 
-#' \code{3}: 1\eqn{\sigma} relative uncertainties (\%).
+#' \code{3}: 1\eqn{\sigma} relative uncertainties (\eqn{\%}).
 #' 
-#' \code{4}: 2\eqn{\sigma} relative uncertainties (\%).
+#' \code{4}: 2\eqn{\sigma} relative uncertainties (\eqn{\%}).
 #'
 #' @param d an object of class \code{\link{diseq}}.
 #' 
@@ -391,15 +391,29 @@ optionalredundancy2cor <- function(X,nc){
             j <- which(is.na(rhoYZ))
         } else {
             j <- 1:nr
-            out <- cbind(X,0)
         }
     } else {
         i <- 1:nr
         j <- 1:nr
-        out <- cbind(X,0,0)
     }
     out[i,7] <- get.cor.75.68(X[i,1],X[i,2],X[i,3],X[i,4],X[i,5],X[i,6])
     out[j,8] <- get.cor.68.76(X[j,1],X[j,2],X[j,3],X[j,4],X[j,5],X[j,6])
+    if ( any(abs(out[i,7])>1) | any(abs(out[j,8])>1) ){
+        out[,8] <- 0
+        U <- iratio('U238U235')[1]
+        J11 <- U*X[,5]
+        J12 <- U*X[,3]
+        J21 <- 1
+        J22 <- 0
+        E11 <- X[,4]^2
+        E22 <- X[,6]^2
+        E12 <- 0
+        out[,7] <- errorprop(J11,J12,J21,J22,E11,E22,E12)[,'cov']/sqrt(X[,2]*X[,4])
+        warning('Redundant ratios of U-Pb data format ',
+                'lead to impossible correlation coefficients. ',
+                'These were replaced with alternative values ',
+                'assuming zero Tera-Wasserburg correlations.')
+    }
     out
 }
 
