@@ -221,7 +221,12 @@ quotient <- function(X,sX,Y,sY,rXY){
 # negative multivariate log likelihood to be fed into R's optim function
 LL.norm <- function(x,covmat){
     (log(2*pi) + determinant(covmat,logarithmic=TRUE)$modulus) +
-        get.concordia.SS(x,covmat)/2
+        stats::mahalanobis(x,center=FALSE,cov=covmat)/2
+}
+
+# convert a sum of squares to a negative univariate normal log likelihood
+SS2LL <- function(SS,nn,df=nn-2){
+    nn*log(SS*sqrt(2*pi)/df) + df/2
 }
 
 set.ellipse.colours <- function(ns=1,levels=NA,col=c('yellow','red'),
@@ -365,7 +370,7 @@ blockinverse3x3 <- function(AA,BB,CC,DD,EE,FF,GG,HH,II){
 #   parms to hold constant (not optimize). If TRUE, the corresponding
 #   parameter in fn() is fixed. Otherwise it's variable and optimised over.
 # lower, upper: a vector with the lower and upper ends of the search
-#   ranges of the free parameters, respectivelyl
+#   ranges of the free parameters, respectively
 # Originally written by Barry Rowlingson, modified by PV
 optifix <- function(parms, fixed, fn, gr = NULL, ...,
                     method = c("Nelder-Mead", "BFGS", "CG", "L-BFGS-B", "SANN"), 
